@@ -9,7 +9,7 @@ from pequod_cli.manager.cli import manager
 from pequod_cli.registry.cli import registry
 from pequod_cli.replicator.cli import replicator
 from pequod_cli.service import CORE_DOMAINS
-from pequod_cli.utils import AliasedGroup, find_cacert_bundle
+from pequod_cli.utils import AliasedGroup, generate_help_tree, find_cacert_bundle
 import click
 import logging
 import os
@@ -20,6 +20,17 @@ DEFAULT_CONFIG_FILE = '~/.pequod-cli.yaml'
 
 CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 
+COMMANDS = {
+    'auth': auth,
+    'manager': manager,
+    'registry': registry,
+    'controller': controller,
+    'controller': replicator,
+    'lbupdater': lbupdater
+}
+
+NON_RESTRICTED = frozenset(['login', 'help'])
+
 
 def print_version(ctx, param, value):
     if not value or ctx.resilient_parsing:
@@ -53,7 +64,7 @@ def cli(ctx, config_file, cluster, verbose):
     if os.path.exists(fn):
         with open(fn) as fd:
             data = yaml.safe_load(fd)
-    if ctx.invoked_subcommand != 'login':
+    if ctx.invoked_subcommand not in NON_RESTRICTED:
         if cluster not in data:
             raise click.UsageError('''Cluster "{}" is not configured yet.
 Please use the "login" command or edit the configuration file {} manually.'''.format(cluster, fn))
@@ -171,13 +182,22 @@ def status(ctx):
                 ok()
 
 
+@cli.command()
+@click.pass_context
+def help(ctx):
+    """
+    Create a commands ordered dict and pass it to tree builder
+    """
+    commands = dict(list(COMMANDS.items()) + list(cli.commands.items()))
+    click.echo('%s'
+               '\n**In order to get more information regarding'
+               ' command execute "pequod [COMMAND] --help"\n'
+               % generate_help_tree(commands))
+
+
 def register_subcommands():
-    cli.add_command(auth)
-    cli.add_command(manager)
-    cli.add_command(registry)
-    cli.add_command(controller)
-    cli.add_command(replicator)
-    cli.add_command(lbupdater)
+    for name, command in COMMANDS.items():
+        cli.add_command(command)
 
 
 def main():
